clc
clear all
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Import data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ex = dlmread('100_6A-163g-min_0-538V.txt', '\t', 'A2..T202');  % read in results from experiment
water= load('water_properties.txt');             % load file that holds water properties for different temperatures [C] in the order: temp,density,specific heat,thermal conductivity, dynamic viscosity, Pr
I = 100;           % measured Current (from file name)
U = 0;          % measured total voltage accross coil element (from file name)
xlRange = 'B1';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Evaluate experimental data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Rtot = 1000*U/I;
Ex_m = mean(Ex,1);                      % caluclate mean values of measurements
Upeak = max(abs(Ex(:,18)),[],1);       % get maximum Voltage

Tcex = (Ex_m(9)+Ex_m(10)+Ex_m(11)+Ex_m(12)+Ex_m(14)+Ex_m(15))/6;     % average coil temperature in C
Tinex = Ex_m(8);                                                    % water temp at inlet in C
Tmidex = (Ex_m(2)+Ex_m(3)+Ex_m(4)+Ex_m(5)+Ex_m(6))/5;                  % average water temperature at T1-T5 in C
Tmiddex = (Ex_m(3)+Ex_m(4)+Ex_m(5))/3;                              % average water temperature at T2-T4 in C
Toutex = Ex_m(16);                                                  % average water temperature at outlet in C

% Look up water properties at diff temperatures
cp_Tinex = interp1(water(:,1),water(:,3),Tinex);
cp_Toutex = interp1(water(:,1),water(:,3),Toutex);
cp_Tmidex = interp1(water(:,1),water(:,3),Tmidex);
cp_Tmiddex = interp1(water(:,1),water(:,3),Tmiddex);

qex = I*U;                                     % Total heat generation in W
qexmid = Upeak*(1/sqrt(2))*I;                 % Generated heat in middle of coil in W
qwex =(Ex(201,19)-Ex(1,19))/200/1000*((273.15+Toutex)*cp_Toutex-(273.15+Tinex)*cp_Tinex);        % total heat transferred into water in W
qwexmid =0.5*(Ex(201,19)-Ex(1,19))/200/1000*((273.15+Tmidex)*cp_Tmidex-(273.15+Tinex)*cp_Tinex);     % heat transferred into water middle part of coil in W (assuming water temp Tmidex)
qwexmidd =0.5*(Ex(201,19)-Ex(1,19))/200/1000*((273.15+Tmiddex)*cp_Tmiddex-(273.15+Tinex)*cp_Tinex);   % heat transferred into water middle part of coil in W (assuming water temp Tmiddex)

qwex1 =(Ex(201,19)-Ex(1,19))/200/1000*(Toutex-Tinex)*(cp_Toutex+cp_Tinex)/2;

diff_qwqex = ((qwex/qex)-1)*100;          % Difference between total resistive losses and heat transferred into water
diff_qwqex1 = ((qwex1/qex)-1)*100;          % Difference between total resistive losses and heat transferred into water
T1T5 = [Ex_m(2);Ex_m(3);Ex_m(4);Ex_m(5);Ex_m(6)];           % put mean values of T1-T5 into a column
stddev_T1T5 = sqrt(var(T1T5))                                 % standard deviation T1-T5  
T2T4 = [Ex_m(3);Ex_m(4);Ex_m(5)];           % put mean values of T2-T4 into a column
stddev_T2T4 = sqrt(var(T2T4))               % standard deviation T2-T4 

var = var(Ex);
stddevT1 = sqrt(var(2));                    % standard deviation
stddevT2 = sqrt(var(3));                    % standard deviation
stddevT3 = sqrt(var(4));                    % standard deviation
stddevT4 = sqrt(var(5));                    % standard deviation
stddevT5 = sqrt(var(6));                    % standard deviation
stddevT6 = sqrt(var(7));                    % standard deviationv
stddevT7 = sqrt(var(8));                    % standard deviation
stddevT8 = sqrt(var(9));                    % standard deviation
stddevT9 = sqrt(var(10));                    % standard deviation
stddevT10 = sqrt(var(11));                    % standard deviation
stddevT11 = sqrt(var(12));                    % standard deviation
stddevT12 = sqrt(var(13));                    % standard deviation
stddevT13 = sqrt(var(14));                    % standard deviation
stddevT14 = sqrt(var(15));                    % standard deviation
stddevT15 = sqrt(var(16));                    % standard deviation

flow = ((Ex(201,19)-Ex(1,19))/200)*60;      % flow rate g/min

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Write results to excel sheet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
filename = 'Standardabweichung_check.xlsx';
A = {flow,Rtot,qex,qexmid,qexmid/qex,qwex,qwex1,qwexmid,qwexmidd,diff_qwqex,diff_qwqex1,Tinex,Toutex,Tcex,Tmidex,Tmiddex,stddev_T1T5,stddev_T2T4,Ex_m(2),Ex_m(3),Ex_m(4),Ex_m(5),Ex_m(6),Ex_m(7),Ex_m(8),Ex_m(9),Ex_m(10),Ex_m(11),Ex_m(12),Ex_m(13),Ex_m(14),Ex_m(15),Ex_m(16),stddevT1,stddevT2,stddevT3,stddevT4,stddevT5,stddevT6,stddevT7,stddevT8,stddevT9,stddevT10,stddevT11,stddevT12,stddevT13,stddevT14,stddevT15,cp_Tinex,cp_Toutex,cp_Tmidex,cp_Tmiddex};
sheet = 1;
%xlRange = 'L24';
xlswrite(filename,A,sheet,xlRange)






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % File format experimental data
% Mistake! It should be Ex(:,1)...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Ex(1,;)       Time in seconds
% Ex(2,;)       T01 in C  Water temp
% Ex(3,;)       T02 in C  Water temp
% Ex(4,;)       T03 in C  Water temp
% Ex(5,;)       T04 in C  Water temp
% Ex(6,;)       T05 in C  Water temp
% Ex(7,;)       T06 in C
% Ex(8,;)       T07 in C  T_in
% Ex(9,;)       T08 in C  Coil temp
% Ex(10,;)      T09 in C  Coil temp 
% Ex(11,;)      T10 in C  Coil temp
% Ex(12,;)      T11 in C  Coil temp
% Ex(13,;)      T12 in C  Coil temp
% Ex(14,;)      T13 in C  Coil temp
% Ex(15,;)      T14 in C  Coil temp
% Ex(16,;)      T15 in C  T_out
% Ex(17,;)      T16 in C  not connected
% Ex(18,;)      Voltage in V
% Ex(19,;)      Mass of water in g
% Ex(20,;)      approximated current in A

% File format simulation data
% Sim(1,;)      Average water vel middle 5mm before coil in m/s
% Sim(2,;)      Average water vel 10deg 5mm before coil in m/s 
% Sim(3,;)      Voltage 10deg in V
% Sim(4,;)      Water mass flow in in kg/s
% Sim(5,;)      Water mass flow out in kg/s
% Sim(6,;)      Total electrical power in W
% Sim(7,;)      Electrical power in middle part of the coil in W
% Sim(8,;)      Q water in in W
% Sim(9,;)      Q water out in W
% Sim(10,;)     Q (heat dissipated by) silicone middle in W
% Sim(11,;)     Q (heat dissipated by) POM in middle (10deg area) in W
% Sim(12,;)     Q aluminum middle in W
% Sim(13,;)     Q (dissipated heat) in the middle area (POM+silicone+aluminum) in W
% Sim(14,;)     Q resistive losses aluminum 10deg area in W
% Sim(15,;)     T01 in C  Water temp
% Sim(16,;)     T02 in C  Water temp
% Sim(17,;)     T03 in C  Water temp
% Sim(18,;)     T08 in C  Water temp
% Sim(19,;)     T09 in C  Water temp
% Sim(20,;)     T10 in C  Water temp
% Sim(21,;)     T11 in C  Water temp
% Sim(22,;)     T12 in C  Water temp
% Sim(23,;)     T13 in C  Water temp
% Sim(24,;)     T14 in C  Water temp
% Sim(25,;)     T15 in C  Water temp
% Sim(26,;)     Water temp after 1st conductor in C
% Sim(27,;)     Water temp after 2nd conductor in C
% Sim(28,;)     Water temp after 3rd conductor in C
% Sim(29,;)     Water temp after 4th conductor in C
% Sim(30,;)     Water temp after 5th conductor in C
% Sim(31,;)     Water temp after 6th conductor in C
% Sim(32,;)     Water temp after 1st silicone in C
% Sim(33,;)     Water temp after 2nd silicone in C
% Sim(34,;)     Water temp after 3rd silicone in C
% Sim(35,;)     Water temp after 4th silicone in C
% Sim(36,;)     Water temp after 5th silicone in C
% Sim(37,;)     Water temp after POM side in C
% Sim(38,;)     Average surface temp alu middle in C
% Sim(39,;)     Average surface temp alu side in C
% Sim(40,;)     Average surface temp silicone 1 in C
% Sim(41,;)     Average surface temp silicone 2 in C
% Sim(42,;)     Average surface temp silicone 3 in C
% Sim(43,;)     Average surface temp silicone 4 in C
% Sim(44,;)     Average surface temp silicone 5 in C
% Sim(45,;)     Average surface temp silicone 6 in C
% Sim(46,;)     Average surface temp silicone 7 in C
% Sim(47,;)     Average surface temp silicone middle in C
% Sim(48,;)     Average surface temp POM in C
% Sim(49,;)     Volume average temp alu middle in C
% Sim(50,;)     Volume average temp alu side in C
% Sim(51,;)     Volume average temp alu in C
% Sim(52,;)     T_in in C
% Sim(53,;)     Current in A
% Sim(54,;)     mass flow rate in kg/min (total, so like in experiment)
