clc
clear all
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Import data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Sim = csvread('6mm_100-8A_22-85Tin_830g-min_fineeemesh.csv',5,1);   % read in data from simulation
xlRange = 'M246';


Tcsim = (Sim(18)+Sim(19)+Sim(20)+Sim(21)+Sim(23)+Sim(24))/6;   % temperature of coil in C
Tinsim = Sim(52);                                              % water temp at inlet in C
Tmidsim = (2*Sim(15)+2*Sim(16)+Sim(17))/5;                         % average temperature after coil (T1-T5) in C
Toutsim = Sim(25);                                              % average outlet temperature in C
qsimmid = Sim(7)*2;                                              % resistive losses in the middle part of the coil in W
qwsimmid = Sim(4)*4182*(Tmidsim-Sim(52));                          % heat transferred into water in the middle of the coil
qwsim = Sim(4)*2*4182*(Sim(25)-Sim(52));                      % heat transferred into water (total)
q_trans2water=(Sim(9)-Sim(8))*2;
qsim = Sim(6)*2                                                % total resistive losses in W  
Tmiddsim = (2*Sim(16)+Sim(17))/3;                              % average temperature after coil (T2-T4) in C
qwsimmidd = Sim(4)*4182*(Tmiddsim-Sim(52));                    % heat transferred into water in the middle of the coil

m_flow = Sim(54)*1/120
Q_in = Sim(8)*Sim(4)/m_flow                     % Qin with simulated flow at inlet
Q_insim = Sim(8)
Q_out = Sim(9)*Sim(5)/m_flow                     % Qout with simulated flow at outlet
Q_outsim = Sim(9)
Qtrans = (Q_out-Q_in)*2
q_trans2water
Continuity = ((Sim(5)-Sim(4))/Sim(4))*100;              % Continuity check

flowsim = Sim(4)*1000*60*2                % mass flow rate in kg/s

Q_al = Sim(12);
Q_si=Sim(10);
Q_AlSi=Q_al+Q_si;
Q_POM=Sim(11);
Q_fail = Sim(55); 
% Sim(10,;)     Q (heat dissipated by) silicone middle in W
% Sim(11,;)     Q (heat dissipated by) POM in middle (10deg area) in W
% Sim(12,;)     Q aluminum middle in W

TsAlumid = Sim(38);
TsAlout = Sim(39);
TsSilimid= Sim(47);
TvolAlumid = Sim(49);

% Sim(38,;)     Average surface temp alu middle in C
% Sim(39,;)     Average surface temp alu side in C
% Sim(47,;)     Average surface temp silicone middle in C
% Sim(49,;)     Volume average temp alu middle in C
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Write results to excel sheet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
filename = 'SimExEvaluation_error.xlsx';
%A = {flow,Rtot,qex,qexmid,qexmid/qex,qwex,qwex1,qwexmid,qwexmidd,diff_qwqex,diff_qwqex1,Tinex,Toutex,Tcex,Tmidex,Tmiddex,stddev_T1T5,stddev_T2T4,Ex_m(2),Ex_m(3),Ex_m(4),Ex_m(5),Ex_m(6),Ex_m(7),Ex_m(8),Ex_m(9),Ex_m(10),Ex_m(11),Ex_m(12),Ex_m(13),Ex_m(14),Ex_m(15),Ex_m(16),stddevT1,stddevT2,stddevT3,stddevT4,stddevT5,stddevT6,stddevT7,stddevT8,stddevT9,stddevT10,stddevT11,stddevT12,stddevT13,stddevT14,stddevT15,cp_Tinex,cp_Toutex,cp_Tmidex,cp_Tmiddex};
B = {flowsim,0,qsim,qsimmid,qsimmid/qsim,qwsim,0,qwsimmid,qwsimmidd,((q_trans2water/qsim)-1)*100,((Qtrans/qsim)-1)*100,Continuity,0,0,0,0,0,Q_al,Q_si,Q_POM,Q_AlSi,Q_fail,0,0,0,0,0,0,0,Tinsim,Toutsim,Tcsim,TsAlumid,TsAlout,TsSilimid,TvolAlumid,Tmidsim,Tmiddsim,0,0,Sim(15),Sim(16),Sim(17),0,0,0,0,Sim(18),Sim(19),Sim(20),Sim(21),Sim(22),Sim(23),Sim(24),Sim(25)};
sheet = 1;
%xlRange = 'L24';
xlswrite(filename,B,sheet,xlRange)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % File format experimental data
% Mistake! It should be Ex(:,1)...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Ex(1,;)       Time in seconds
% Ex(2,;)       T01 in C  Water temp
% Ex(3,;)       T02 in C  Water temp
% Ex(4,;)       T03 in C  Water temp
% Ex(5,;)       T04 in C  Water temp
% Ex(6,;)       T05 in C  Water temp
% Ex(7,;)       T06 in C
% Ex(8,;)       T07 in C  T_in
% Ex(9,;)       T08 in C  Coil temp
% Ex(10,;)      T09 in C  Coil temp 
% Ex(11,;)      T10 in C  Coil temp
% Ex(12,;)      T11 in C  Coil temp
% Ex(13,;)      T12 in C  Coil temp
% Ex(14,;)      T13 in C  Coil temp
% Ex(15,;)      T14 in C  Coil temp
% Ex(16,;)      T15 in C  T_out
% Ex(17,;)      T16 in C  not connected
% Ex(18,;)      Voltage in V
% Ex(19,;)      Mass of water in g
% Ex(20,;)      approximated current in A

% File format simulation data
% Sim(1,;)      Average water vel middle 5mm before coil in m/s
% Sim(2,;)      Average water vel 10deg 5mm before coil in m/s 
% Sim(3,;)      Voltage 10deg in V
% Sim(4,;)      Water mass flow in in kg/s
% Sim(5,;)      Water mass flow out in kg/s
% Sim(6,;)      Total electrical power in W
% Sim(7,;)      Electrical power in middle part of the coil in W
% Sim(8,;)      Q water in in W
% Sim(9,;)      Q water out in W
% Sim(10,;)     Q (heat dissipated by) silicone middle in W
% Sim(11,;)     Q (heat dissipated by) POM in middle (10deg area) in W
% Sim(12,;)     Q aluminum middle in W
% Sim(13,;)     Q (dissipated heat) in the middle area (POM+silicone+aluminum) in W
% Sim(14,;)     Q resistive losses aluminum 10deg area in W
% Sim(15,;)     T01 in C  Water temp
% Sim(16,;)     T02 in C  Water temp
% Sim(17,;)     T03 in C  Water temp
% Sim(18,;)     T08 in C  Water temp
% Sim(19,;)     T09 in C  Water temp
% Sim(20,;)     T10 in C  Water temp
% Sim(21,;)     T11 in C  Water temp
% Sim(22,;)     T12 in C  Water temp
% Sim(23,;)     T13 in C  Water temp
% Sim(24,;)     T14 in C  Water temp
% Sim(25,;)     T15 in C  Water temp
% Sim(26,;)     Water temp after 1st conductor in C
% Sim(27,;)     Water temp after 2nd conductor in C
% Sim(28,;)     Water temp after 3rd conductor in C
% Sim(29,;)     Water temp after 4th conductor in C
% Sim(30,;)     Water temp after 5th conductor in C
% Sim(31,;)     Water temp after 6th conductor in C
% Sim(32,;)     Water temp after 1st silicone in C
% Sim(33,;)     Water temp after 2nd silicone in C
% Sim(34,;)     Water temp after 3rd silicone in C
% Sim(35,;)     Water temp after 4th silicone in C
% Sim(36,;)     Water temp after 5th silicone in C
% Sim(37,;)     Water temp after POM side in C
% Sim(38,;)     Average surface temp alu middle in C
% Sim(39,;)     Average surface temp alu side in C
% Sim(40,;)     Average surface temp silicone 1 in C
% Sim(41,;)     Average surface temp silicone 2 in C
% Sim(42,;)     Average surface temp silicone 3 in C
% Sim(43,;)     Average surface temp silicone 4 in C
% Sim(44,;)     Average surface temp silicone 5 in C
% Sim(45,;)     Average surface temp silicone 6 in C
% Sim(46,;)     Average surface temp silicone 7 in C
% Sim(47,;)     Average surface temp silicone middle in C
% Sim(48,;)     Average surface temp POM in C
% Sim(49,;)     Volume average temp alu middle in C
% Sim(50,;)     Volume average temp alu side in C
% Sim(51,;)     Volume average temp alu in C
% Sim(52,;)     T_in in C
% Sim(53,;)     Current in A
% Sim(54,;)     mass flow rate in kg/min (total, so like in experiment)
% Sim(55,;)     Q from inner part to outer part (incl. silicone, alu, POM)
